@@ -8,9 +8,7 @@ from __future__ import print_function, unicode_literals
 
 import argparse
 import base64
-import binascii
 import collections
-import contextlib
 import errno
 import glob
 import io
@@ -110,28 +108,28 @@ _kernel_info = collections.namedtuple(typename="kernel_info", field_names=("name
 LOGGING_CONFIG = {
     "formatters": {
         "default": {
-            "format": "[%(levelname)s] %(name)s: %(message)s",
+            "format": "%(asctime)s - %(levelname)s :: %(name)s :: %(message)s",
+            # Use this string to format the creation time of the record.
+            "datefmt": "%Y-%m-%d--%H-%M-%S",
         },
     },
     "handlers": {
+        "console": {
+            "class": "logging.StreamHandler",
+            "formatter": "default",
+            "stream": "ext://sys.stdout",
+        },
         "logfile": {
             "class": "logging.FileHandler",
             "encoding": "utf-8",
             "filename": os.path.join(tempfile.gettempdir(), "notebook-environments.log"),
             "formatter": "default",
-            "mode": "wt",
-        },
-        "stdout": {
-            "class": "logging.StreamHandler",
-            "formatter": "default",
-            "stream": "ext://sys.stdout",
+            "mode": "at",
         },
     },
     "loggers": {
         "notebook-environments": {
-            "handlers": ["logfile", "stdout"],
-            # Don't send it up this namespace for additional handling.
-            "propagate": False,
+            "handlers": ["console", "logfile"],
         },
     },
     # Set the preferred schema version.
@@ -150,7 +148,7 @@ __all__ = (
     "show_kernels",
 )
 
-__version__ = "0.8.10"
+__version__ = "0.8.11"
 
 
 def _in_virtual_environment():
@@ -264,10 +262,8 @@ def _write_python_logos(path):
     for logo_name, logo_image in logos_spec.items():
         try:
             with io.open(os.path.join(path, logo_name), mode="wb") as stream_out:
-                # Skip this step when an unexpected error has occurred.
-                with contextlib.suppress(binascii.Error):
-                    # Create a new python logo on the current machine.
-                    stream_out.write(base64.b64decode(logo_image))
+                # Create a new python logo on the current machine.
+                stream_out.write(base64.b64decode(logo_image))
         except (IOError, OSError) as err:
             _logger.error("It's impossible to create python logos on the current machine.")
             _logger.debug("An unexpected error occurred at this program runtime:", exc_info=True)
@@ -369,8 +365,8 @@ def initialize_new_notebook_environment():
     try:
         from jupyter_core.paths import jupyter_path  # noqa
     except ImportError:
-        def jupyter_path(path):  # this function is to return a list
-            return [_get_data_path(path)]
+        def jupyter_path(subdirs):  # this function is to return a list
+            return [_get_data_path(subdirs)]
 
     # Find and remove all python kernels from the working notebook server.
     for path in jupyter_path("kernels"):
